#~ $,="\x02"
#~ $\="\x03\n"

#
#-###################################################################
#
# You can use this to test the due dates for AR1100ESCT [RMLJ]. Just change the year var 'yr'.
# The test below runs through the entire year, calculating the due date for each of the 4 installments per
# end date.
#
yr = 2014

#
#-###################################################################
#
# This computes the due date based on the Twelve Month Year Ended date and
# the installment number. The algorithm 'backs up' 12 months and starts from the
# starting date of the 12 month period - the year is adjusted accordingly. For each
# installment number, the ending month is set going forward from the start date
# with the year being adjusted as needed.
#
# Example: 12 month year ended 03/31/14:
#
#	Installment 1 -> due date is 07/15/2013
#	Installment 2 -> due date is 09/15/2013
#	Installment 3-> due date is 12/15/2013
#	Installment 4 -> due date is 03/15/2014
#
# There is a routine in the shared area [display_AR1100ESCT_due_dates.rbw]
# that you can run and compare to the due dates printed on the form itself.
#
# Returns an empty string for a 'bad' date.
#
def get_due_date(date, install_num)

	due_date = ""

	if (date.delete("^0-9") =~ /^(\d\d)\d\d(\d{4})$/)
		
		mn = $1.to_i
		yr = $2.to_i

		if ((1..11) === mn)
			mn = mn +1
			yr = yr -1
		else
			mn = 1
		end

		mn = mn + 3 * install_num - (install_num < 2 ? 0 : 1)

		if (mn > 12)

			mn = mn % 12
			yr += 1
		end

		due_date = "#{'%02i' % mn}/15/#{yr}"
	end
	due_date
end

#
#-###################################################################
#
# Here is the test routine:
#
end_dates = ["01/31/#{yr}","02/28/#{yr}","03/31/#{yr}","04/30/#{yr}","05/31/#{yr}","06/30/#{yr}","07/31/#{yr}","08/31/#{yr}","09/30/#{yr}","10/31/#{yr}","11/30/#{yr}","12/31/#{yr}"]

end_dates.each do |date|

	print "\nEnd Date: #{date}\n\n"

	1.upto(4) do |install_num|

		due_date = get_due_date(date, install_num)
		print "\tInstallment Number #{install_num}: #{due_date}\n"
	end
end
